@@ -105,7 +105,7 @@ class FactorySchemas:
         }
     )
 
-    FACTORY_MATCH_MODEL = Schema(
+    FACTORY_MATCH = Schema(
         name_mapping={
             "id": "id",
             "offset": "offset",
@@ -114,3 +114,20 @@ class FactorySchemas:
             "frequency_skew": "frequencyskew",
         }
     )
+
+    FACTORY_ATTRIBUTES_ARTIST = Schema(
+        name_mapping={
+            "name": "name",
+            "url": "url",
+            "artist_bio": "artistBio",
+            "genre_names": "genreNames",
+        }
+    )
+
+    FACTORY_ARTIST_V2 = Schema(
+        name_mapping={
+            "id": "id",
+            "type": "type",
+            "attributes": "attributes",
+        }
+    )
