@@ -2,11 +2,12 @@ from typing import Union
 
 from shazamio.factory_misc import FACTORY_ARTIST
 from shazamio.factory_misc import FACTORY_TRACK
-from shazamio.models import ArtistInfo
-from shazamio.models import ArtistV2
-from shazamio.models import ResponseTrack
-from shazamio.models import TrackInfo
-from shazamio.models import YoutubeData
+from shazamio.schemas.artists import ArtistInfo
+from shazamio.schemas.artists import ArtistResponse
+from shazamio.schemas.artists import ArtistV2
+from shazamio.schemas.models import ResponseTrack
+from shazamio.schemas.models import TrackInfo
+from shazamio.schemas.models import YoutubeData
 
 
 class Serialize:
@@ -18,6 +19,10 @@ class Serialize:
     def youtube(cls, data):
         return FACTORY_TRACK.load(data, YoutubeData)
 
+    @classmethod
+    def artist_v2(cls, data) -> ArtistResponse:
+        return ArtistResponse.parse_obj(data)
+
     @classmethod
     def artist(cls, data):
         return FACTORY_ARTIST.load(data, Union[ArtistV2, ArtistInfo])
