@@ -1,12 +1,18 @@
 import pathlib
-from typing import Union
-from pydub import AudioSegment
+from enum import Enum
 from io import BytesIO
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Union
 
 import aiofiles
 import aiohttp
 from aiohttp import ContentTypeError
+from pydub import AudioSegment
+
 from shazamio.exceptions import FailedDecodeJson
+from shazamio.schemas.artists import ArtistQuery
 
 SongT = Union[str, pathlib.Path, bytes, bytearray]
 FileT = Union[str, pathlib.Path]
@@ -28,7 +34,6 @@ async def get_file_bytes(file: FileT) -> bytes:
 
 
 async def get_song(data: SongT) -> Union[AudioSegment]:
-
     if isinstance(data, (str, pathlib.Path)):
         song_bytes = await get_file_bytes(file=data)
         return AudioSegment.from_file(BytesIO(song_bytes))
@@ -38,3 +43,28 @@ async def get_song(data: SongT) -> Union[AudioSegment]:
 
     if isinstance(data, AudioSegment):
         return data
+
+
+class QueryBuilder:
+    def __init__(
+        self,
+        source: List[Union[str, Enum]],
+    ):
+        self.source = source
+
+    def to_str(self) -> str:
+        return ",".join(self.source)
+
+
+class ArtistQueryGenerator:
+    def __init__(
+        self,
+        source: Optional[ArtistQuery] = None,
+    ):
+        self.source = source
+
+    def params(self) -> Dict[str, str]:
+        return {
+            "extend": QueryBuilder(source=self.source.extend or []).to_str(),
+            "views": QueryBuilder(source=self.source.views or []).to_str(),
+        }
